@@ -29,12 +29,16 @@
 #include <stdio.h>
 #include <sys/types.h>
 #include "calc.h"
+#include "alloc.h"
 #include "value.h"
 #include "file.h"
 #include "blkcpy.h"
 #include "str.h"
 
 
+#include "banned.h"	/* include after system header <> includes */
+
+
 /*
  * copystod - copy num indexed items from source value to destination value
  *
